==> mediawiki-1.15.5-noarch-P1.tgz: opt/htdocs/mediawiki-1.15.5/languages/messages/MessagesSs.php <==
<?php
/** Swati (SiSwati)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jatrobat
 * @author MF-Warburg
 * @author Sibande
 */

$messages = array(
# Dates
'sunday'        => 'LiSontfo',
'monday'        => 'Msombuluko',
'tuesday'       => 'Lesibili',
'wednesday'     => 'Lesitsatfu',
'thursday'      => 'Lesine',
'friday'        => 'Lesihlanu',
'saturday'      => 'Mgcibelo',
'sun'           => 'LiSontfo',
'mon'           => 'Msombuluko',
'tue'           => 'Lesibili',
'wed'           => 'Lesitsatfu',
'thu'           => 'Lesine',
'fri'           => 'Lesihlanu',
'sat'           => 'Mgcibelo',
'january'       => 'Bhimbidvwane',
'february'      => 'iNdlovana',
'march'         => 'iNdlovu',
'april'         => 'Mabasa',
'may_long'      => 'iNkhwekhweti',
'june'          => 'iNhlaba',
'july'          => 'Kholwane',
'august'        => 'iNgci',
'september'     => 'iNyoni',
'october'       => 'iMphala',
'november'      => 'Lweti',
'december'      => 'iNgongoni',
'january-gen'   => 'Bhimbidvwane',
'february-gen'  => 'iNdlovana',
'march-gen'     => 'iNdlovu',
'april-gen'     => 'Mabasa',
'may-gen'       => 'iNkhwekhweti',
'june-gen'      => 'iNhlaba',
'july-gen'      => 'Kholwane',
'august-gen'    => 'iNgci',
'september-gen' => 'iNyoni',
'october-gen'   => 'iMphala',
'november-gen'  => 'Lweti',
'december-gen'  => 'iNgongoni',
'jan'           => 'Bhi',
'feb'           => 'iNdlova',
'mar'           => 'iNdlovu',
'apr'           => 'Mab',
'may'           => 'iNkhwe',
'jun'           => 'iNhla',
'jul'           => 'Kho',
'aug'           => 'iNgci',
'sep'           => 'iNyo',
'oct'           => 'iMpha',
'nov'           => 'Lwe',
'dec'           => 'iNgo',

# Categories related messages
'category_header'          => 'Makhasi lakulomkhakha "$1"',
'subcategories'            => 'Mikhakha lengaphansi',
'category-media-header'    => 'i-Media lekulomkhakha "$1"',
'category-empty'           => "''Lomkhakha ute makhasi nobe i-media lewuphetse.''",
'hidden-category-category' => 'Mikhakha lefihliwe', # Name of the category where hidden categories will be listed
'listingcontinuesabbrev'   => 'chubeka.',

'mainpagetext' => "'''i-MediaWiki seyifakeke ngalokuphelele.'''",

'about'          => 'Kabanti',
'article'        => 'Likhasi lentfo',
'newwindow'      => '(kuvulekela tukweli-window lelisha)',
'cancel'         => 'Yekela',
'qbfind'         => 'Tfola',
'qbbrowse'       => 'Browse',
'qbedit'         => 'Hlela',
'qbpageoptions'  => 'Lelikhasi',
'qbmyoptions'    => 'Makhasi ami',
'qbspecialpages' => 'Emakhasi labalulekile',
'moredotdotdot'  => 'Lokunyenti...',
'mypage'         => 'Likhasi lami',
'mytalk'         => 'Tingcoco tami',
'anontalk'       => 'Tingcogco letentwe ngulelikheli lale-IP',

'returnto'          => 'Buyela ku $1.',
'help'              => 'Sita',
'search'            => 'Sesha',
'searchbutton'      => 'Sesha',
'go'                => 'Hamba',
'searcharticle'     => 'Hamba',
'history'           => 'Umlandvo walelikhasi',
'history_short'     => 'Umlandvo',
'info_short'        => 'Lwati',
'print'             => 'Print',
'edit'              => 'Hlela',
'create'            => 'Yakha',
'editthispage'      => 'Hlela lelikhasi',
'create-this-page'  => 'Yakha lelikhasi',
'delete'            => 'Sula',
'deletethispage'    => 'Sula lelikhasi',
'protect'           => 'Vikela',
'protect_change'    => 'gucula',
'protectthispage'   => 'Vikela lelikhasi',
'unprotect'         => 'Yekelela',
'unprotectthispage' => 'Yekelela lelikhasi',
'newpage'           => 'Likhasi lelisha',
'talkpage'          => 'Coca ngalelikhasi',
'talkpagelinktext'  => 'Ingcoco',
'specialpage'       => 'Likhasi lelibalulekile',
'personaltools'     => 'Mathulusi emuntfu',
'postcomment'       => 'Sihloko lesinsha',
'articlepage'       => 'Bona likhasi lelicuketse',
'talk'              => 'Ingcoco',
'views'             => 'Kubukeka',
'toolbox'           => 'Libhokisi Lemathulusi',
'userpage'          => 'Buna likhasi lemuntfu',
'projectpage'       => 'Bona likhasi leprojekthi',
'imagepage'         => 'Bona lelifayela likhasi',
'mediawikipage'     => 'Bona likhasi lemiyaleto',
'viewhelppage'      => 'Bona likhasi lelusito',
'categorypage'      => 'Bona likhasi lemikhakha',
'viewtalkpage'      => 'Bona ingcoco',
'otherlanguages'    => 'Ngaletinye tilwimi',
'redirectedfrom'    => '(Utfunyelelwe likhasi $1)',
'redirectpagesub'   => 'Likhasi lekutfumela',
'lastmodifiedat'    => 'Lelikhasi ligcine kushintjwa ngetingu $1, ngo $2.', # $1 date, $2 time
'viewcount'         => 'Lelikhasi selibonwe {{PLURAL:$1|kanye|kayi $1}}.',
'protectedpage'     => 'Likhasi lelivikelekile',
'jumpto'            => 'Zuba ku:',
'jumptosearch'      => 'sesha',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Kabanti nge {{SITENAME}}',
'aboutpage'            => 'Project:Kabanti',
'copyright'            => 'Lokucuketfwe kungaphansi kwe $1.',
'copyrightpage'        => '{{ns:project}}:Malungelo ekukhicita',
'currentevents'        => 'Tentakalo tanyalo',
'currentevents-url'    => 'Project:Tentakalo tanyalo',
'edithelp'             => 'Lusito ngekuhlela',
'edithelppage'         => 'Help:Kuhlela',
'helppage'             => 'Help:Lokucuketfwe',
'mainpage'             => 'Likhasi Lelikhulu',
'mainpage-description' => 'Likhasi lelikhulu',
'policy-url'           => 'Project:Umtsetfo',
'portal'               => 'Likhefi le-inthanethi',
'portal-url'           => 'Project:Likhefi leinthanethi',

'badaccess'        => 'Liphutsa lemalungelo',
'badaccess-group0' => 'Awukavunyelwa kwenta lesento lobowutama kusenta.',
'badaccess-groups' => 'Lesento losicelile sincishiselwe bantfu labakule {{PLURAL:$2|ncumbi|labakunobe nguyiphi incumbi}}: $1.',

'ok'                      => 'Kulungile',
'retrievedfrom'           => 'Kutsatfwe ku "$1"',
'youhavenewmessages'      => 'Una $1 ($2).',
'newmessageslink'         => 'milayeto lemisha',
'newmessagesdifflink'     => 'ingucuko yekugcina',
'youhavenewmessagesmulti' => 'Unemilayeto lemisha nge $1',
'editsection'             => 'hlela',
'editold'                 => 'hlela',
'viewsourceold'           => 'Bona kwakheka',
'editlink'                => 'hlela',
'viewsourcelink'          => 'Bona kwakheka',
'editsectionhint'         => 'Hlela sihloko: $1',
'toc'                     => 'Lokucuketfwe',
'showtoc'                 => 'khomba',
'hidetoc'                 => 'fihla',
'thisisdeleted'           => 'Bona nobe buyisela esimweni $1?',
'viewdeleted'             => 'Bona $1?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Likhasi',
'nstab-user' => 'Umuntfu',
'nstab-help' => 'Likhasi lelusito',

# Login and logout pages
'uid'                => 'Matisi Wemuntfu:',
'yourlanguage'       => 'Lulwimi:',
'loginlanguagelabel' => 'Lulwimi: $1',

# Search results
'search-mwsuggest-enabled'  => 'nemibono',
'search-mwsuggest-disabled' => 'kute mibono',
'search-relatedarticle'     => 'Lokuhlobene',
'mwsuggest-disable'         => 'Vala losito/mibono ye AJAX',
'searchrelated'             => 'lokuhlobene',
'searchall'                 => 'konke',
'showingresults'            => "Ngaphasi kukhonjiswa kuya ku {{PLURAL:$1|'''1''' umphumela|'''$1''' miphumela}} kucalwa nga #'''$2'''.",
'showingresultsnum'         => "Ngaphansi kukhonjiswa {{PLURAL:$3|'''1''' umphumela|'''$3''' miphumela}} kucalwa nga #'''$2'''.",
'search-nonefound'          => 'Kute umphume lotfolwe/lofanele lesicelo sakho.',
'powersearch'               => 'Sesha ngalokuphakeme',
'powersearch-legend'        => 'Sesha ngalokuphakeme',
'powersearch-ns'            => 'Sesha ku namespaces:',
'powersearch-redir'         => 'Makhasi latfumelayo',
'powersearch-field'         => 'Sesha i',
'search-external'           => 'Sesha ngelithulusi langaphandle',
'searchdisabled'            => '{{SITENAME}} kusesha kuvinjiwe.
Ungasesha nge Google.
Naka kutsi makhasi abo e {{SITENAME}} angaba sekadlulelwe sikhatsi.',

# Preferences page
'qbsettings-none'   => 'Kute',
'searchresultshead' => 'Sesha',

# Special:ListFiles
'listfiles_date' => 'Lusuku',
'listfiles_name' => 'Ligama',
'listfiles_user' => 'Umuntfu',

# File description page
'filehist-datetime' => 'Lusuku/Sikhatsi',
'filehist-user'     => 'Umuntfu',

'brokenredirects-edit' => 'hlela',

'withoutinterwiki-submit' => 'Khomba',

# Miscellaneous special pages
'move' => 'Khweshisa',

# Book sources
'booksources-go' => 'Hamba',

# Special:Log
'specialloguserlabel' => 'Umuntfu:',

# Special:AllPages
'allpagessubmit' => 'Hamba',

# Special:LinkSearch
'linksearch-ok' => 'Sesha',

# Special:ListUsers
'listusers-submit' => 'Khomba',

# Watchlist
'watch'   => 'Gadza',
'unwatch' => 'Yekela kugadza',

# Restrictions (nouns)
'restriction-edit'   => 'Hlela',
'restriction-move'   => 'Khweshisa',
'restriction-create' => 'Create',

# Undelete
'undelete-search-submit' => 'Sesha',

'sp-contributions-submit' => 'Sesha',

# Block/unblock
'ipblocklist-submit' => 'Sesha',
'proxyblocksuccess'  => 'Kwentekile.',

# Move page
'movelogpage' => 'Khweshisa i-log',

# Namespace 8 related
'allmessagesname' => 'Ligama',

# Tooltip help for the actions
'tooltip-search' => 'Sesha i-{{SITENAME}}',
'tooltip-p-logo' => 'Vakashela likhasi lelikhulu',

# Special:NewFiles
'ilsubmit' => 'Sesha',

# Multipage image navigation
'imgmultigo' => 'Hamba!',

# Table pager
'table_pager_limit_submit' => 'Hamba',

# Special:Version
'version-specialpages' => 'Emakhasi labalulekile',

# Special:SpecialPages
'specialpages' => 'Emakhasi labalulekile',

);

==> mediawiki-1.16.4-noarch-P1.tgz: opt/htdocs/mediawiki-1.16.4/languages/messages/MessagesSs.php <==
<?php
/** Swati (SiSwati)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jatrobat
 * @author MF-Warburg
 * @author Sibande
 */

$messages = array(
# Dates
'sunday'        => 'LiSontfo',
'monday'        => 'Msombuluko',
'tuesday'       => 'Lesibili',
'wednesday'     => 'Lesitsatfu',
'thursday'      => 'Lesine',
'friday'        => 'Lesihlanu',
'saturday'      => 'Mgcibelo',
'sun'           => 'LiSontfo',
'mon'           => 'Msombuluko',
'tue'           => 'Lesibili',
'wed'           => 'Lesitsatfu',
'thu'           => 'Lesine',
'fri'           => 'Lesihlanu',
'sat'           => 'Mgcibelo',
'january'       => 'Bhimbidvwane',
'february'      => 'iNdlovana',
'march'         => 'iNdlovu',
'april'         => 'Mabasa',
'may_long'      => 'iNkhwekhweti',
'june'          => 'iNhlaba',
'july'          => 'Kholwane',
'august'        => 'iNgci',
'september'     => 'iNyoni',
'october'       => 'iMphala',
'november'      => 'Lweti',
'december'      => 'iNgongoni',
'january-gen'   => 'Bhimbidvwane',
'february-gen'  => 'iNdlovana',
'march-gen'     => 'iNdlovu',
'april-gen'     => 'Mabasa',
'may-gen'       => 'iNkhwekhweti',
'june-gen'      => 'iNhlaba',
'july-gen'      => 'Kholwane',
'august-gen'    => 'iNgci',
'september-gen' => 'iNyoni',
'october-gen'   => 'iMphala',
'november-gen'  => 'Lweti',
'december-gen'  => 'iNgongoni',
'jan'           => 'Bhi',
'feb'           => 'iNdlova',
'mar'           => 'iNdlovu',
'apr'           => 'Mab',
'may'           => 'iNkhwe',
'jun'           => 'iNhla',
'jul'           => 'Kho',
'aug'           => 'iNgci',
'sep'           => 'iNyo',
'oct'           => 'iMpha',
'nov'           => 'Lwe',
'dec'           => 'iNgo',

# Categories related messages
'category_header'          => 'Makhasi lakulomkhakha "$1"',
'subcategories'            => 'Mikhakha lengaphansi',
'category-media-header'    => 'i-Media lekulomkhakha "$1"',
'category-empty'           => "''Lomkhakha ute makhasi nobe i-media lewuphetse.''",
'hidden-category-category' => 'Mikhakha lefihliwe',
'listingcontinuesabbrev'   => 'chubeka.',
'index-category'           => 'Makhasi lacokelelwe',
'noindex-category'         => 'Makhasi lasabalele',

'mainpagetext' => "'''i-MediaWiki seyifakeke ngalokuphelele.'''",

'about'         => 'Kabanti',
'article'       => 'Likhasi lentfo',
'newwindow'     => '(kuvulekela tukweli-window lelisha)',
'cancel'        => 'Yekela',
'moredotdotdot' => 'Lokunyenti...',
'mypage'        => 'Likhasi lami',
'mytalk'        => 'Tingcoco tami',
'anontalk'      => 'Tingcogco letentwe ngulelikheli lale-IP',

# Cologne Blue skin
'qbfind'         => 'Tfola',
'qbbrowse'       => 'Browse',
'qbedit'         => 'Hlela',
'qbpageoptions'  => 'Lelikhasi',
'qbmyoptions'    => 'Makhasi ami',
'qbspecialpages' => 'Emakhasi labalulekile',

# Vector skin
'vector-action-addsection'   => 'Ngeta sihloko',
'vector-action-move'         => 'Khweshisa',
'vector-namespace-help'      => 'Likhasi lelusito',
'vector-namespace-main'      => 'Likhasi',
'vector-namespace-mediawiki' => 'Mlayeto',
'vector-namespace-special'   => 'Likhasi lelibalulekile',
'vector-namespace-talk'      => 'Ingcoco',
'vector-namespace-user'      => 'Likhasi lemuntfu',
'vector-view-create'         => 'Create',
'vector-view-edit'           => 'Hlela',
'vector-view-history'        => 'Bona umlandvo',
'vector-view-view'           => 'Fundza',
'actions'                    => 'Tento',

'returnto'          => 'Buyela ku $1.',
'help'              => 'Sita',
'search'            => 'Sesha',
'searchbutton'      => 'Sesha',
'go'                => 'Hamba',
'searcharticle'     => 'Hamba',
'history'           => 'Umlandvo walelikhasi',
'history_short'     => 'Umlandvo',
'info_short'        => 'Lwati',
'print'             => 'Print',
'edit'              => 'Hlela',
'create'            => 'Yakha',
'editthispage'      => 'Hlela lelikhasi',
'create-this-page'  => 'Yakha lelikhasi',
'delete'            => 'Sula',
'deletethispage'    => 'Sula lelikhasi',
'protect'           => 'Vikela',
'protect_change'    => 'gucula',
'protectthispage'   => 'Vikela lelikhasi',
'unprotect'         => 'Yekelela',
'unprotectthispage' => 'Yekelela lelikhasi',
'newpage'           => 'Likhasi lelisha',
'talkpage'          => 'Coca ngalelikhasi',
'talkpagelinktext'  => 'Ingcoco',
'specialpage'       => 'Likhasi lelibalulekile',
'personaltools'     => 'Mathulusi emuntfu',
'postcomment'       => 'Sihloko lesinsha',
'articlepage'       => 'Bona likhasi lelicuketse',
'talk'              => 'Ingcoco',
'views'             => 'Kubukeka',
'toolbox'           => 'Libhokisi Lemathulusi',
'userpage'          => 'Buna likhasi lemuntfu',
'projectpage'       => 'Bona likhasi leprojekthi',
'imagepage'         => 'Bona lelifayela likhasi',
'mediawikipage'     => 'Bona likhasi lemiyaleto',
'viewhelppage'      => 'Bona likhasi lelusito',
'categorypage'      => 'Bona likhasi lemikhakha',
'viewtalkpage'      => 'Bona ingcoco',
'otherlanguages'    => 'Ngaletinye tilwimi',
'redirectedfrom'    => '(Utfunyelelwe likhasi $1)',
'redirectpagesub'   => 'Likhasi lekutfumela',
'lastmodifiedat'    => 'Lelikhasi ligcine kushintjwa ngetingu $1, ngo $2.',
'viewcount'         => 'Lelikhasi selibonwe {{PLURAL:$1|kanye|kayi $1}}.',
'protectedpage'     => 'Likhasi lelivikelekile',
'jumpto'            => 'Zuba ku:',
'jumptosearch'      => 'sesha',
'view-pool-error'   => 'Siyacolisa, maseva etfu agwele kakhulu ngalesikhatsi.
Kunebantfu labanyenti labatama kubona lelikhasi.
Sicela ume kancane ngaphambi lwekuphindze ubone lelikhasi.

$1',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Kabanti nge {{SITENAME}}',
'aboutpage'            => 'Project:Kabanti',
'copyright'            => 'Lokucuketfwe kungaphansi kwe $1.',
'copyrightpage'        => '{{ns:project}}:Malungelo ekukhicita',
'currentevents'        => 'Tentakalo tanyalo',
'currentevents-url'    => 'Project:Tentakalo tanyalo',
'edithelp'             => 'Lusito ngekuhlela',
'edithelppage'         => 'Help:Kuhlela',
'helppage'             => 'Help:Lokucuketfwe',
'mainpage'             => 'Likhasi Lelikhulu',
'mainpage-description' => 'Likhasi lelikhulu',
'policy-url'           => 'Project:Umtsetfo',
'portal'               => 'Likhefi le-inthanethi',
'portal-url'           => 'Project:Likhefi le-inthanethi',

'badaccess'        => 'Liphutsa lemalungelo',
'badaccess-group0' => 'Awukavunyelwa kwenta lesento lobowutama kusenta.',
'badaccess-groups' => 'Lesento losicelile sincishiselwe bantfu labakule {{PLURAL:$2|ncumbi|labakunobe nguyiphi incumbi}}: $1.',

'ok'                      => 'Kulungile',
'retrievedfrom'           => 'Kutsatfwe ku "$1"',
'youhavenewmessages'      => 'Una $1 ($2).',
'newmessageslink'         => 'milayeto lemisha',
'newmessagesdifflink'     => 'ingucuko yekugcina',
'youhavenewmessagesmulti' => 'Unemilayeto lemisha nge $1',
'editsection'             => 'hlela',
'editold'                 => 'hlela',
'viewsourceold'           => 'Bona kwakheka',
'editlink'                => 'hlela',
'viewsourcelink'          => 'Bona kwakheka',
'editsectionhint'         => 'Hlela sihloko: $1',
'toc'                     => 'Lokucuketfwe',
'showtoc'                 => 'khomba',
'hidetoc'                 => 'fihla',
'thisisdeleted'           => 'Bona nobe buyisela esimweni $1?',
'viewdeleted'             => 'Bona $1?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Likhasi',
'nstab-user' => 'Umuntfu',
'nstab-help' => 'Likhasi lelusito',

# Login and logout pages
'loginlanguagelabel' => 'Lulwimi: $1',

# Search results
'search-mwsuggest-enabled'  => 'nemibono',
'search-mwsuggest-disabled' => 'kute mibono',
'search-relatedarticle'     => 'Lokuhlobene',
'mwsuggest-disable'         => 'Vala losito/mibono ye AJAX',
'searcheverything-enable'   => 'Sesha onke ma namespaces',
'searchrelated'             => 'lokuhlobene',
'searchall'                 => 'konke',
'showingresults'            => "Ngaphasi kukhonjiswa kuya ku {{PLURAL:$1|'''1''' umphumela|'''$1''' miphumela}} kucalwa nga #'''$2'''.",
'showingresultsnum'         => "Ngaphansi kukhonjiswa {{PLURAL:$3|'''1''' umphumela|'''$3''' miphumela}} kucalwa nga #'''$2'''.",
'showingresultsheader'      => "{{PLURAL:$5|Umphumela '''$1''' of '''$3'''|Imiphumela '''$1 - $2''' ye '''$3'''}} ya '''$4'''",
'search-nonefound'          => 'Kute umphume lotfolwe/lofanele lesicelo sakho.',
'powersearch'               => 'Sesha ngalokuphakeme',
'powersearch-legend'        => 'Sesha ngalokuphakeme',
'powersearch-ns'            => 'Sesha ku namespaces:',
'powersearch-redir'         => 'Makhasi latfumelayo',
'powersearch-field'         => 'Sesha i',
'powersearch-togglelabel'   => 'Buka:',
'powersearch-toggleall'     => 'Konke',
'powersearch-togglenone'    => 'Kute',
'search-external'           => 'Sesha ngelithulusi langaphandle',
'searchdisabled'            => '{{SITENAME}} kusesha kuvinjiwe.
Ungasesha nge Google.
Naka kutsi makhasi abo e {{SITENAME}} angaba sekadlulelwe sikhatsi.',

# Quickbar
'qbsettings-none' => 'Kute',

# Preferences page
'searchresultshead' => 'Sesha',
'uid'               => 'Matisi Wemuntfu:',
'yourlanguage'      => 'Lulwimi:',

# Special:ListFiles
'listfiles_date' => 'Lusuku',
'listfiles_name' => 'Ligama',
'listfiles_user' => 'Umuntfu',

# File description page
'filehist-datetime' => 'Lusuku/Sikhatsi',
'filehist-user'     => 'Umuntfu',

'brokenredirects-edit' => 'hlela',

'withoutinterwiki-submit' => 'Khomba',

# Miscellaneous special pages
'move' => 'Khweshisa',

# Book sources
'booksources-go' => 'Hamba',

# Special:Log
'specialloguserlabel' => 'Umuntfu:',

# Special:AllPages
'allpagessubmit' => 'Hamba',

# Special:LinkSearch
'linksearch-ok' => 'Sesha',

# Special:ListUsers
'listusers-submit' => 'Khomba',

# Watchlist
'watch'   => 'Gadza',
'unwatch' => 'Yekela kugadza',

# Restrictions (nouns)
'restriction-edit'   => 'Hlela',
'restriction-move'   => 'Khweshisa',
'restriction-create' => 'Create',

# Undelete
'undelete-search-submit' => 'Sesha',

'sp-contributions-talk'   => 'ingcoco',
'sp-contributions-submit' => 'Sesha',

# Block/unblock
'ipblocklist-submit' => 'Sesha',
'proxyblocksuccess'  => 'Kwentekile.',

# Move page
'movelogpage' => 'Khweshisa i-log',

# Namespace 8 related
'allmessagesname' => 'Ligama',

# Tooltip help for the actions
'tooltip-search' => 'Sesha i-{{SITENAME}}',
'tooltip-p-logo' => 'Vakashela likhasi lelikhulu',

# Special:NewFiles
'ilsubmit' => 'Sesha',

# Multipage image navigation
'imgmultigo' => 'Hamba!',

# Table pager
'table_pager_limit_submit' => 'Hamba',

# Special:Version
'version-specialpages' => 'Emakhasi labalulekile',

# Special:SpecialPages
'specialpages' => 'Emakhasi labalulekile',

);
